==> malisiscore-1.7.10-0.12.5-sources.jar: net/malisis/core/util/chunkblock/IChunkBlock.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014 Ordinastie
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package net.malisis.core.util.chunkblock;

/**
 * The IChunkBlock defines a block that will be store in chunks data directly.
 *
 * @author Ordinastie
 */
public interface IChunkBlock
{
	/**
	 * Gets the block range.<br>
	 * Defines the distance for which the block will store itself into chunk data.<br>
	 *
	 * @return the int
	 */
	public int blockRange();
}

==> malisiscore-1.10.2-4.2.3-sources.jar: net/malisis/core/util/chunkblock/IChunkBlock.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014 Ordinastie
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package net.malisis.core.util.chunkblock;

import net.minecraft.util.math.BlockPos;

/**
 * The IChunkBlock defines a block that will be store in chunks data directly.
 *
 * @author Ordinastie
 */
public interface IChunkBlock
{
	/**
	 * Gets the block range.<br>
	 * Defines the distance for which the block will store itself into chunk data.<br>
	 *
	 * @return the int
	 */
	public int blockRange();

	/**
	 * Checks if {@link BlockPos} {@code to} is within range of {@code from}.
	 *
	 * @param from the from
	 * @param to the to
	 * @return true, if is in range
	 */
	public default boolean isInRange(BlockPos from, BlockPos to)
	{
		return from.distanceSq(to) <= blockRange() * blockRange();
	}
}
